<?php
/**
*
* @package phpBB3
* @author eduardor2k and mtrs 31.10.08
* @version $Id$ 1.0.0 03.07.2009
* @copyright (c) 2008 eduardor2k@redr2k.com, alex at agileware dot net as I took two functions by them from php.net
* @copyright (c) 2008 mtrs 
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/
/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit();
}

function post_subject_uppercase_check($string)
{
	global $auth, $config, $mode, $user;

	//Post subject process
	similar_text($string, utf8_strtoupper($string), $percent);	
	
	if ($auth->acl_get('u_check_uppercase') || ($config['aau_enable_subject'] && (strlen($string) > 3 && $percent >= $config['aau_uppercase_ratio']) && $mode == 'post' && $user->data['user_posts'] < $config['aau_posts_limit']))
	{
		if ($config['aau_enable_correction'])
		{
			if ($user->data['user_lang'] == "tr")
			{
				$string = remove_shouting_title_tr($string);
			}
			else
			{
				//$string = mb_convert_case($string, MB_CASE_TITLE, "UTF-8");//alternative function for title case, uncomment to use, and comment the line below
				$string = remove_shouting_title_en($string);				
			}
		}
		else
		{
			return false;
		}
	}
	
	//We uppercase first letters of every word in subject line
	if ($config['aau_subject_uc_first'] && $mode == 'post' && $user->data['user_posts'] < $config['aau_posts_limit'])
	{
		if ($user->data['user_lang'] == "tr")
		{
			$string = mb_ucfirst_tr($string);
		}
		else
		{
			$string = utf8_ucfirst($string);
		}	
	}	
	
	return $string;
}
 
function message_text_uppercase_check($string)
{
	global $auth, $config, $mode, $user;
	
	//Post text process
	$string_caps = (utf8_strlen($string) > 8000) ? (utf8_substr($string, 0, 8000)) : $string;
	similar_text($string_caps, utf8_strtoupper($string_caps), $percent);
		
	if ($auth->acl_get('u_check_uppercase') || ($config['aau_enable_message'] && $user->data['user_posts'] < $config['aau_posts_limit'] && strlen($string) >= 20 && $percent >= $config['aau_uppercase_ratio']))
	{
		if ($config['aau_enable_correction'])
		{			
			if ($user->data['user_lang'] == "tr")
			{
				//We use a different function for Turkish as "I","ı","İ","i" translations are different
				$string = remove_shouting_utf8_tr($string);
			}
			else
			{
				//$string = remove_shouting($string); //Uncomment this line and comment the line below for faster but no UTF8 but message text correction
				$string = remove_shouting_utf8($string);
			}
		}
		else// if ($percent >= $config['aau_uppercase_ratio'])
		{
			return false;
		}
	}		
	
	return $string;
}	
 
//This text correction function does not support utf8 
function remove_shouting($string)
{
	$string = strtolower(trim($string));
	
	for($i = 0; $i < (strlen($string) - 1); $i++)
	{      
		if($i == 0)
		{
			$string[$i] = strtoupper($string[$i]);
		}
			
		if($string[$i] == "." || $string[$i] == "?" || $string[$i] == "!" || $string[$i+1] == chr(10))
		{
			while($string[$i+1] == " " || $string[$i+1] == chr(10))
			{
				$i++;
			}
			$string[$i+1] = strtoupper($string[$i+1]);
			$i++;
		}
	}      

	return $string;
}
//Turkish strtolower function: fixes i,ı, I,İ issue
function mb_strtolower_tr($string)
{
	$string = str_replace("I","ı", $string);
	$string = mb_strtolower($string);
	
	return $string;
}
//Turkish strtoupper function: fixes i,ı, I,İ issue
function mb_strtoupper_tr($string)
{
	$string = str_replace(array("ı","i"), array("I","İ"), $string);
	$string = mb_strtoupper($string);
	
	return $string;
}
//Turkish ucfirst function:  fixes i,ı, I,İ issue
function mb_ucfirst_tr($string) 
{	
	$string = mb_strtoupper_tr(mb_substr($string, 0, 1, 'UTF-8')) . mb_substr($string, 1, mb_strlen($string), 'UTF-8'); 
	
	return $string; 
}
//Title correction function UTF8-en
function remove_shouting_title_en($string) 
{
	$words = mb_split(' ', $string);
    $newwords = array();

    foreach ($words as $word)
    {
		$word = utf8_strtolower($word);
		$word = utf8_ucfirst($word);
		array_push($newwords, $word);
	}

	$string = join(" ", $newwords);
	//We fix some short strings
	$string = str_replace(array(" A ", " The ", " Of ", " And ", " To ", " In ", " On ", "&Amp;", "Ii", "Iii", "Vi", "Vii", "Viii", "VIi", "Ix"), array(" a ", " the ", " of ", " and ", " to ", " in ", " on ", "&", "II", "III", "VI", "VII", "VIII", "VII", "IX"), $string . " ");//exceptions list
	$string = trim(utf8_ucfirst($string));
	
	return $string;
}
//Title correction function UTF8-en

//Turkish title correction function: fixes i,ı, I,İ issue
function remove_shouting_title_tr($string) 
{
	$string = mb_strtolower_tr($string);
	$words = mb_split(' ', $string);
    $newwords = array();

    foreach ($words as $word)
    {		
		$new_string = mb_ucfirst_tr($word);
		array_push($newwords, $new_string);
	}

	$string = join(" ", $newwords);
	$string = str_replace(array(" Ve "," Mi?"," Mı?"," Mu?"," Misiniz?"," Mısınız?"," Musunuz?"," Ki "," De "," Da "), array(" ve "," mi?"," mı?"," mu?"," misiniz?"," mısınız?"," musunuz?"," ki "," de ", " da "), $string);
	
	return $string;
}
//Turkish message text correction function: fixes i,ı, I,İ issue in Turkish
function remove_shouting_utf8_tr($string)
{
	$string = str_replace(array("...", "..", ".", "?", "!"), array("````.", "``.","``.", "`|?", "´´!"), $string);
	$words = mb_split('[.?!]', $string);
    $newwords = array();

    foreach ($words as $word)
    {
		$word = str_replace("I", "ı", $word);
		$word = mb_strtolower($word);
			
		$new_string = "";
		$word_len = mb_strlen($word);
		
		for($i = 0; $i < $word_len; )
		{ 
			while ($word[$i] == " " || $word[$i] == chr(9) || $word[$i] == chr(10))
			{
				$new_string .= $word[$i];
				$i++;
			}

			if ($word[$i] == chr(10))
			{
				$new_string .= $word[$i];
				$i++;
				$new_string .= mb_ucfirst_tr(mb_substr($word, $i, $word_len, 'UTF-8'));
			}
			else
			{
				$new_string .= mb_ucfirst_tr(mb_substr($word, $i, $word_len, 'UTF-8'));
			}	
			array_push($newwords, $new_string);
			
			break;
		}
	}

	$string = join("", $newwords);
	$string = str_replace(array("``", "`|", "´´", "İmage", ".Jpg", ".Bmp", ".Png", ".Gif"), array(".", "?", "!", "image", ".jpg", ".bmp", ".png", ".gif"), $string);

	return $string;
}


// Message text correction function, supports utf8, used for languages other than Turkish
function remove_shouting_utf8($string)
{
	$string = str_replace(array("...", "..", ".", "?", "!"), array("````.", "``.","``.", "`|?", "´´!"), $string);
	$words = mb_split('[.?!]', $string);
    $newwords = array();

    foreach ($words as $word)
    {
		$word = mb_strtolower($word);
			 				
		$new_string = '';
		$word_len = mb_strlen($word);
		
		for($i = 0; $i < $word_len; )
		{ 
			while ($word[$i] == " " || $word[$i] == chr(9) || $word[$i] == chr(10))
			{
				$new_string .= $word[$i];
				$i++;
			}

			if ($word[$i] == chr(10))
			{
				$new_string .= $word[$i];
				$i++;
				$new_string .= utf8_ucfirst(mb_substr($word, $i, $word_len, 'UTF-8'));
			}
			else
			{
				$new_string .= utf8_ucfirst(mb_substr($word, $i, $word_len, 'UTF-8'));
			}	
			array_push($newwords, $new_string);
			
			break;
		}
	}

	$string = join("", $newwords);
	$string = str_replace(array("``", "`|", "´´", "İmage", ".Jpg", ".Bmp", ".Png", ".Gif"), array(".", "?", "!", "image", ".jpg", ".bmp", ".png", ".gif"), $string);

	return $string;
}

?>